@@ -5,15 +5,21 @@ from narwhals._compliant.dataframe import (
     CompliantLazyFrame,
     EagerDataFrame,
 )
-from narwhals._compliant.expr import CompliantExpr, EagerExpr, LazyExpr
+from narwhals._compliant.expr import (
+    CompliantExpr,
+    DepthTrackingExpr,
+    EagerExpr,
+    LazyExpr,
+    LazyExprNamespace,
+)
 from narwhals._compliant.group_by import (
     CompliantGroupBy,
     DepthTrackingGroupBy,
     EagerGroupBy,
-    LazyGroupBy,
 )
 from narwhals._compliant.namespace import (
     CompliantNamespace,
+    DepthTrackingNamespace,
     EagerNamespace,
     LazyNamespace,
 )
@@ -23,7 +29,16 @@ from narwhals._compliant.selectors import (
     EagerSelectorNamespace,
     LazySelectorNamespace,
 )
-from narwhals._compliant.series import CompliantSeries, EagerSeries
+from narwhals._compliant.series import (
+    CompliantSeries,
+    EagerSeries,
+    EagerSeriesCatNamespace,
+    EagerSeriesDateTimeNamespace,
+    EagerSeriesListNamespace,
+    EagerSeriesNamespace,
+    EagerSeriesStringNamespace,
+    EagerSeriesStructNamespace,
+)
 from narwhals._compliant.typing import (
     CompliantExprT,
     CompliantFrameT,
@@ -37,13 +52,8 @@ from narwhals._compliant.typing import (
     NativeFrameT_co,
     NativeSeriesT_co,
 )
-from narwhals._compliant.when_then import (
-    CompliantThen,
-    CompliantWhen,
-    EagerWhen,
-    LazyThen,
-    LazyWhen,
-)
+from narwhals._compliant.when_then import CompliantThen, CompliantWhen, EagerWhen
+from narwhals._compliant.window import WindowInputs
 
 __all__ = [
     "CompliantDataFrame",
@@ -60,7 +70,9 @@ __all__ = [
     "CompliantSeriesT",
     "CompliantThen",
     "CompliantWhen",
+    "DepthTrackingExpr",
     "DepthTrackingGroupBy",
+    "DepthTrackingNamespace",
     "EagerDataFrame",
     "EagerDataFrameT",
     "EagerExpr",
@@ -68,17 +80,22 @@ __all__ = [
     "EagerNamespace",
     "EagerSelectorNamespace",
     "EagerSeries",
+    "EagerSeriesCatNamespace",
+    "EagerSeriesDateTimeNamespace",
+    "EagerSeriesListNamespace",
+    "EagerSeriesNamespace",
+    "EagerSeriesStringNamespace",
+    "EagerSeriesStructNamespace",
     "EagerSeriesT",
     "EagerWhen",
     "EvalNames",
     "EvalSeries",
     "IntoCompliantExpr",
     "LazyExpr",
-    "LazyGroupBy",
+    "LazyExprNamespace",
     "LazyNamespace",
     "LazySelectorNamespace",
-    "LazyThen",
-    "LazyWhen",
     "NativeFrameT_co",
     "NativeSeriesT_co",
+    "WindowInputs",
 ]
